package com.agilecontrol.nea.core.util;

import com.agilecontrol.nea.core.util.CookieNotSupportedException;
import com.agilecontrol.nea.util.Validator;
import javax.servlet.http.Cookie;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.codec.binary.Hex;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class CookieKeys {

   private static final Logger logger = LoggerFactory.getLogger(CookieKeys.class);
   public static final String COOKIE_SUPPORT = "NEA_COOKIE_SUPPORT";
   public static final String COMPANY_ID = "COMPANY_ID";
   public static final String GUEST_LANGUAGE_ID = "GUEST_LANGUAGE_ID";
   public static final String ID = "ID";
   public static final String JSESSIONID = "jsessionid";
   public static final String LOGIN = "NEAUSER";
   public static final String TOKEN = "token";
   public static final String PORTAL_SESSION_TOKEN = "PTOKEN";
   public static final String PASSWORD = "NEAPASSWORD";
   public static final String REMEMBER_ME = "REMEMBER_ME";
   public static final String SCREEN_NAME = "SCREEN_NAME";
   public static final int MAX_AGE = 31536000;
   public static final int VERSION = 0;


   public static void addCookie(HttpServletRequest request, HttpServletResponse response, Cookie cookie) {
      addCookie(request, response, cookie, request.isSecure());
   }

   public static void addCookie(HttpServletRequest request, HttpServletResponse response, Cookie cookie, boolean secure) {
      String name = cookie.getName();
      Cookie[] cks = request.getCookies();
      if(cks != null) {
         for(int originalValue = 0; originalValue < cks.length; ++originalValue) {
            if(cks[originalValue].getName().equals(name)) {
               cks[originalValue].setMaxAge(0);
               response.addCookie(cks[originalValue]);
               break;
            }
         }
      }

      String var8 = cookie.getValue();
      String encodedValue = var8;
      if(isEncodedCookie(name) && var8 != null) {
         encodedValue = new String(Hex.encodeHex(var8.getBytes()));
      }

      cookie.setSecure(secure);
      cookie.setValue(encodedValue);
      cookie.setVersion(0);
      response.addCookie(cookie);
   }

   public static void addCookie(HttpServletRequest request, HttpServletResponse response, Cookie cookie, boolean secure, int expiry) {
      String name = cookie.getName();
      Cookie[] cks = request.getCookies();
      if(cks != null) {
         for(int originalValue = 0; originalValue < cks.length; ++originalValue) {
            if(cks[originalValue].getName().equals(name)) {
               cks[originalValue].setMaxAge(0);
               response.addCookie(cks[originalValue]);
               break;
            }
         }
      }

      String var9 = cookie.getValue();
      String encodedValue = var9;
      if(isEncodedCookie(name) && var9 != null) {
         encodedValue = new String(Hex.encodeHex(var9.getBytes()));
      }

      cookie.setPath("/");
      cookie.setSecure(secure);
      cookie.setValue(encodedValue);
      cookie.setVersion(0);
      cookie.setMaxAge(expiry);
      response.addCookie(cookie);
   }

   public static void addSupportCookie(HttpServletRequest request, HttpServletResponse response) {
      String cookieSupport = getCookie(request, "NEA_COOKIE_SUPPORT");
      if(Validator.isNull(cookieSupport)) {
         Cookie cookieSupportCookie = new Cookie("NEA_COOKIE_SUPPORT", "true");
         cookieSupportCookie.setPath("/");
         cookieSupportCookie.setMaxAge(31536000);
         addCookie(request, response, cookieSupportCookie);
      }

   }

   public static Cookie getCookieObj(HttpServletRequest request, String name) {
      Cookie[] cookies = request.getCookies();
      if(cookies == null) {
         return null;
      } else {
         for(int i = 0; i < cookies.length; ++i) {
            Cookie cookie = cookies[i];
            String cookieName = cookie.getName();
            if(name.equalsIgnoreCase(cookieName)) {
               return cookie;
            }
         }

         return null;
      }
   }

   public static String getCookieRaw(HttpServletRequest request, String name) {
      Cookie[] cookies = request.getCookies();
      if(cookies == null) {
         return null;
      } else {
         for(int i = 0; i < cookies.length; ++i) {
            Cookie cookie = cookies[i];
            String cookieName = cookie.getName();
            if(name.equalsIgnoreCase(cookieName)) {
               return cookie.getValue();
            }
         }

         return null;
      }
   }

   public static String getCookie(HttpServletRequest request, String name) {
      String value = getCookieRaw(request, name);
      if(value != null && isEncodedCookie(name)) {
         try {
            String originalValue = new String(Hex.decodeHex(value.toCharArray()));
            if(logger.isDebugEnabled()) {
               logger.debug("Get encoded cookie " + name);
               logger.debug("Hex encoded value " + value);
               logger.debug("Original value " + originalValue);
            }

            return originalValue;
         } catch (Exception var5) {
            if(logger.isWarnEnabled()) {
               logger.warn(var5.getMessage());
            }

            return value;
         }
      } else {
         return value;
      }
   }

   public static String getDomain(HttpServletRequest request) {
      return getDomain((String)request.getServerName());
   }

   public static String getDomain(String host) {
      if(host == null) {
         return null;
      } else if(Validator.isIPAddress(host)) {
         return host;
      } else {
         int x = host.lastIndexOf(".");
         if(x <= 0) {
            return null;
         } else {
            int y = host.lastIndexOf(".", x - 1);
            if(y <= 0) {
               return "." + host;
            } else {
               int z = host.lastIndexOf(".", y - 1);
               String domain = null;
               if(z <= 0) {
                  domain = host.substring(y);
               } else {
                  domain = host.substring(z);
               }

               return domain;
            }
         }
      }
   }

   public static boolean hasSessionId(HttpServletRequest request) {
      String jsessionid = getCookie(request, "jsessionid");
      return jsessionid != null;
   }

   public static boolean isEncodedCookie(String name) {
      return name.equals("ID") || name.startsWith("NEAUSER") || name.startsWith("NEAPASSWORD") || name.equals("SCREEN_NAME");
   }

   public static void validateSupportCookie(HttpServletRequest request) throws CookieNotSupportedException {
      String cookieSupport = getCookie(request, "NEA_COOKIE_SUPPORT");
      if(Validator.isNull(cookieSupport)) {
         throw new CookieNotSupportedException("@cookie-not-supported@");
      }
   }

}
